@@ -249,7 +249,7 @@ copies_changed (GtkAdjustment *adj, GnomePrintCopiesSelector *gpc)
 static void
 gnome_print_copies_selector_init (GnomePrintCopiesSelector *gpc)
 {
-	GtkWidget *table, *label, *frame;
+	GtkWidget *table, *label, *frame, *l;
 	GtkAdjustment *adj;
 	GdkPixbuf *pb;
 	AtkObject *atko;
@@ -271,9 +271,9 @@ gnome_print_copies_selector_init (GnomePrintCopiesSelector *gpc)
 	gtk_container_add (GTK_CONTAINER(frame), GTK_WIDGET (table));
 	gtk_widget_show (table);
 
-	label = gtk_label_new_with_mnemonic (_("N_umber of copies:"));
-	gtk_widget_show (label);
-	gtk_table_attach_defaults ((GtkTable *)table, label, 0, 1, 0, 1);
+	l = gtk_label_new_with_mnemonic (_("N_umber of copies:"));
+	gtk_widget_show (l);
+	gtk_table_attach_defaults ((GtkTable *)table, l, 0, 1, 0, 1);
 
 	adj = (GtkAdjustment *) gtk_adjustment_new(1, 1, 1000, 1.0, 10.0, 10.0);
 	gpc->copies = gtk_spin_button_new (adj, 1.0, 0);
@@ -281,7 +281,9 @@ gnome_print_copies_selector_init (GnomePrintCopiesSelector *gpc)
 	gtk_widget_show (gpc->copies);
 	gtk_table_attach_defaults ((GtkTable *)table, gpc->copies, 1, 2, 0, 1);
 
-	gtk_label_set_mnemonic_widget ((GtkLabel *) label, gpc->copies);
+	gnome_print_set_atk_relation (label, GTK_WIDGET (gpc->copies));
+	gnome_print_set_atk_relation (l, GTK_WIDGET (gpc->copies));
+	gtk_label_set_mnemonic_widget ((GtkLabel *) l, gpc->copies);
 
 	pb = gdk_pixbuf_new_from_xpm_data (nocollate_xpm);
 	gpc->collate_image = gtk_image_new_from_pixbuf (pb);
@@ -292,6 +294,7 @@ gnome_print_copies_selector_init (GnomePrintCopiesSelector *gpc)
 	atk_image_set_image_description (ATK_IMAGE (atko), _("Image showing the collation sequence when multiple copies of the document are printed"));
 
 	gpc->collate = gtk_check_button_new_with_mnemonic (_("_Collate"));
+	gnome_print_set_atk_relation (label, GTK_WIDGET (gpc->collate));
 	gtk_widget_show(gpc->collate);
 	gtk_table_attach_defaults((GtkTable *)table, gpc->collate, 1, 2, 1, 2);
 
