@@ -111,8 +111,8 @@ struct _GpaPaperPreviewItem {
 
 	/* Nodes and handlers we are listening to */
 	GPANode *gpa_config;
-	GPANode *node[4];
-	gulong handler[4];
+	GPANode *node[6];
+	gulong handler[6];
 	gulong handler_config;
 };
 
@@ -692,7 +692,7 @@ gpa_paper_preview_item_set_layout (GpaPaperPreviewItem *pp, const GSList *affine
 
 
 static void
-gpa_paper_preview_item_reload_values (GPANode *node, guint flags, GpaPaperPreviewItem *item)
+gpa_paper_preview_item_reload_values (GpaPaperPreviewItem *item)
 {
 	gdouble ml, mr, mt, mb, w, h;
 	GnomePrintLayoutData *lyd;
@@ -804,8 +804,10 @@ gpa_paper_preview_item_disconnect (GpaPaperPreviewItem *pp)
 static void
 gpa_paper_preview_item_connect (GpaPaperPreviewItem *pp)
 {
-	const guchar *paths[] = {
+	const gchar *paths[] = {
 		GNOME_PRINT_KEY_PAPER_SIZE,
+		GNOME_PRINT_KEY_PAPER_WIDTH,
+		GNOME_PRINT_KEY_PAPER_HEIGHT,
 		GNOME_PRINT_KEY_PAPER_ORIENTATION,
 		GNOME_PRINT_KEY_PAGE_ORIENTATION,
 		GNOME_PRINT_KEY_LAYOUT,
@@ -817,8 +819,8 @@ gpa_paper_preview_item_connect (GpaPaperPreviewItem *pp)
 	for (i = 0; i < max; i++) {
 		pp->node[i] = gpa_node_get_child_from_path (pp->gpa_config, paths[i]);
 		if (pp->node[i])
-			pp->handler[i] = g_signal_connect (G_OBJECT (pp->node[i]), "modified",
-							   (GCallback) gpa_paper_preview_item_reload_values, pp);
+			pp->handler[i] = g_signal_connect_swapped (G_OBJECT (pp->node[i]), "modified",
+				(GCallback) gpa_paper_preview_item_reload_values, pp);
 		else
 			pp->handler[i] = 0;
 	}
@@ -829,7 +831,7 @@ gpa_paper_preview_item_config_modified_cb (GPANode *node, guint flags, GpaPaperP
 {
 	gpa_paper_preview_item_disconnect (pp);
 	gpa_paper_preview_item_connect (pp);
-	gpa_paper_preview_item_reload_values (NULL, 0, pp);
+	gpa_paper_preview_item_reload_values (pp);
 }
 
 GnomeCanvasItem *
@@ -851,7 +853,7 @@ gpa_paper_preview_item_new (GnomePrintConfig *config, GtkWidget *canvas)
 					       gpa_paper_preview_item_config_modified_cb, pp);
 	gpa_paper_preview_item_load_colors (pp, canvas);
 	g_signal_connect (G_OBJECT (canvas), "style_set", G_CALLBACK (gpa_paper_preview_item_style_color_cb), pp);
-	gpa_paper_preview_item_reload_values (NULL, 0, pp);
+	gpa_paper_preview_item_reload_values (pp);
 
 	gpa_paper_preview_item_connect (pp);
 	
