@@ -34,7 +34,6 @@
 #include <gtk/gtk.h>
 #include <libgnomeprint/gnome-print-config.h>
 #include <libgnomeprintui/gnome-print-dialog.h>
-#include <libgnomeprintui/gnome-print-dialog-private.h>
 #include <libgnomeprintui/gnome-printer-selector.h>
 #include <libgnomeprintui/gpaui/gpa-tree-viewer.h>
 #include <libgnomeprintui/gpaui/gpa-printer-selector.h>
@@ -76,7 +75,7 @@ typedef struct _TestCase TestCase;
 
 struct _TestCase {
 	TestRetval (*function) (void);
-	const guchar *description;
+	const gchar *description;
 };
 
 #define max_num_test ((sizeof (test_cases) / sizeof (test_cases[0]))-1)
@@ -113,13 +112,19 @@ static const TestCase test_cases[] = {
 static gint
 test_dialog_get_num_pages (GtkWidget *dialog)
 {
-	return g_list_length (GTK_NOTEBOOK (GNOME_PRINT_DIALOG (dialog)->notebook)->children);
+	GtkNotebook *notebook;
+
+	g_object_get (G_OBJECT (dialog), "notebook", &notebook, NULL);
+	return g_list_length (notebook->children);
 }
 
 static void
 test_dialog_show_page (GtkWidget *dialog, gint page)
 {
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (GNOME_PRINT_DIALOG (dialog)->notebook), page);
+	GtkNotebook *notebook;
+
+	g_object_get (G_OBJECT (dialog), "notebook", &notebook, NULL);
+	gtk_notebook_set_current_page (notebook, page);
 	
 }
 
@@ -144,15 +149,15 @@ test_pos_window (GtkWidget *window)
 
 	gtk_window_get_size (GTK_WINDOW (window), &width, &height);
 	
-	if ((y + height) > gdk_screen_height ()) {
+	if ((y + height) > gdk_screen_get_height (gdk_screen_get_default ())) {
 		x += new_x + RIGHT_LEFT_FRAME;
 		new_x = 0;
 		y = PANEL_HEIGHT;
 	}
 
-	if (x + width > gdk_screen_width ())
+	if (x + width > gdk_screen_get_width (gdk_screen_get_default ()))
 		x = 0;
-	if (y + height > gdk_screen_height ())
+	if (y + height > gdk_screen_get_height (gdk_screen_get_default ()))
 		y = 0;
 	
 	new_x = (width > new_x) ? width : new_x;
@@ -168,7 +173,7 @@ test_dialog_show_all_pages (GnomePrintConfig *config)
 	GtkWidget *dialog;
 	
 	job = gnome_print_job_new (config);
-	dialog = gnome_print_dialog_new (job, "Sample Print Dialog",
+	dialog = gnome_print_dialog_new (job, (const guchar *) "Sample Print Dialog",
 					 GNOME_PRINT_DIALOG_RANGE | GNOME_PRINT_DIALOG_COPIES);
 	gtk_widget_show (dialog);
 	test_pos_window (dialog);
@@ -178,7 +183,7 @@ test_dialog_show_all_pages (GnomePrintConfig *config)
 	}
 
 	job = gnome_print_job_new (config);
-	dialog = gnome_print_dialog_new (job, "Sample Print Dialog",
+	dialog = gnome_print_dialog_new (job, (const guchar *) "Sample Print Dialog",
 					 GNOME_PRINT_DIALOG_RANGE | GNOME_PRINT_DIALOG_COPIES);
 	gtk_widget_show (dialog);
 	test_dialog_show_page (dialog, 1);
@@ -189,7 +194,7 @@ test_dialog_show_all_pages (GnomePrintConfig *config)
 	}
 
 	job = gnome_print_job_new (config);
-	dialog = gnome_print_dialog_new (job, "Sample Print Dialog",
+	dialog = gnome_print_dialog_new (job, (const guchar *) "Sample Print Dialog",
 					 GNOME_PRINT_DIALOG_RANGE | GNOME_PRINT_DIALOG_COPIES);
 	gtk_widget_show (dialog);
 	test_pos_window (dialog);
@@ -241,8 +246,9 @@ test_printer_changes (void)
 	GPANode *node, *printers, *child;
 	GSList *list, *l;
 	GtkWidget *dialog;
-	GtkWidget *option_menu;
+	GtkTreeSelection *sel;
 	gint len;
+	GnomePrinterSelector *printer;
 
 	config = gnome_print_config_default ();
 	
@@ -250,14 +256,16 @@ test_printer_changes (void)
 
 	node = GNOME_PRINT_CONFIG_NODE (config);
 	g_return_val_if_fail (GPA_IS_NODE (node), TEST_RETVAL_ERROR);
-	printers = gpa_node_get_child_from_path (node, "Globals.Printers");
+	printers = gpa_node_get_child_from_path (node, (const guchar *) "Globals.Printers");
 	g_return_val_if_fail (GPA_IS_NODE (printers), TEST_RETVAL_ERROR);	
 
 	/* Make sure the gtkoptionmenu changes */
 	callback_count = 0;
-	option_menu = GPA_PRINTER_SELECTOR (GNOME_PRINTER_SELECTOR (GNOME_PRINT_DIALOG (dialog)->printer)->printers)->menu;
-	g_return_val_if_fail (GTK_IS_OPTION_MENU (option_menu), TEST_RETVAL_ERROR);
-	g_signal_connect (G_OBJECT (option_menu), "changed",
+	g_object_get (G_OBJECT (dialog), "printer_selector", &printer, NULL);
+	sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (
+			GPA_PRINTER_SELECTOR (printer->printers)->treeview));
+	g_return_val_if_fail (GTK_IS_TREE_SELECTION (sel), TEST_RETVAL_ERROR);
+	g_signal_connect (G_OBJECT (sel), "changed",
 			  (GCallback) increment_callback_count, NULL);
 
 	test_run (1000);
@@ -270,7 +278,7 @@ test_printer_changes (void)
 	
 	l = list;
 	while (l) {
-		if (!gnome_print_config_set (config, "Printer", gpa_node_id (l->data))) {
+		if (!gnome_print_config_set (config, (const guchar *) "Printer", gpa_node_id (l->data))) {
 			g_print ("Could not set the Printer to %s\n", gpa_node_id (l->data));
 			return TEST_RETVAL_ERROR;
 		}
@@ -321,13 +329,13 @@ test_paper_changes (void)
 	config = gnome_print_config_default ();
 	test_dialog_show_all_pages (config);
 
-	gnome_print_config_set (config, "Printer", "GENERIC");
+	gnome_print_config_set (config, (const guchar *) "Printer", (const guchar *) "GENERIC");
 
 	test_run (1000);
 
 	max = sizeof (papers) / sizeof (gchar *);
 	for (i = 0; i < max; i++) {
-		if (!gnome_print_config_set (config, GNOME_PRINT_KEY_PAPER_SIZE, papers[i])) {
+		if (!gnome_print_config_set (config, (const guchar *) GNOME_PRINT_KEY_PAPER_SIZE, (const guchar *) papers[i])) {
 			g_print ("Could not set paper size to %s\n", papers[i]);
 			return TEST_RETVAL_ERROR;
 		}
@@ -336,14 +344,14 @@ test_paper_changes (void)
 
 	max = sizeof (orientations) / sizeof (gchar *);
 	for (i = 0; i < max; i++) {
-		if (!gnome_print_config_set (config, GNOME_PRINT_KEY_PAGE_ORIENTATION, orientations[i])) {
+		if (!gnome_print_config_set (config, (const guchar *) GNOME_PRINT_KEY_PAGE_ORIENTATION, (const guchar *) orientations[i])) {
 			g_print ("Could not set the page orientation to %s\n", orientations[i]);
 			return TEST_RETVAL_ERROR;
 		}
 		test_run (150);
 	}
 	for (i = 0; i < max; i++) {
-		if (!gnome_print_config_set (config, GNOME_PRINT_KEY_PAPER_ORIENTATION, orientations[i])) {
+		if (!gnome_print_config_set (config, (const guchar *) GNOME_PRINT_KEY_PAPER_ORIENTATION, (const guchar *) orientations[i])) {
 			g_print ("Could not set the paper orientation to %s\n", orientations[i]);
 			return TEST_RETVAL_ERROR;
 		}
@@ -352,7 +360,7 @@ test_paper_changes (void)
 
 	max = sizeof (layouts) / sizeof (gchar *);
 	for (i = 0; i < max; i++) {
-		if (!gnome_print_config_set (config, GNOME_PRINT_KEY_LAYOUT, layouts[i])) {
+		if (!gnome_print_config_set (config, (const guchar *) GNOME_PRINT_KEY_LAYOUT, (const guchar *) layouts[i])) {
 			g_print ("Could not set the Layout to %s\n", layouts[i]);
 			return TEST_RETVAL_ERROR;
 		}
@@ -375,19 +383,19 @@ test_dialog_flags (void)
 	config = gnome_print_config_default ();
 
 	job = gnome_print_job_new (config);
-	dialog = gnome_print_dialog_new (job, "Sample Print Dialog",
+	dialog = gnome_print_dialog_new (job, (const guchar *) "Sample Print Dialog",
 					 0);
 	gtk_widget_show (dialog);
 	test_pos_window (dialog);
 
 	job = gnome_print_job_new (config);
-	dialog = gnome_print_dialog_new (job, "Sample Print Dialog",
+	dialog = gnome_print_dialog_new (job, (const guchar *) "Sample Print Dialog",
 					 GNOME_PRINT_DIALOG_RANGE);
 	gtk_widget_show (dialog);
 	test_pos_window (dialog);
 	
 	job = gnome_print_job_new (config);
-	dialog = gnome_print_dialog_new (job, "Sample Print Dialog",
+	dialog = gnome_print_dialog_new (job, (const guchar *) "Sample Print Dialog",
 					 GNOME_PRINT_DIALOG_COPIES);
 	gtk_widget_show (dialog);
 	test_pos_window (dialog);
@@ -404,7 +412,7 @@ test_show (void)
 {
 	GtkWidget *dialog;
 
-	dialog = gnome_print_dialog_new (NULL, "Sample Print Dialog", 0);
+	dialog = gnome_print_dialog_new (NULL, (const guchar *) "Sample Print Dialog", 0);
 
 	gtk_widget_show (dialog);
 
@@ -425,7 +433,7 @@ test_multiple (void)
 
 	job = gnome_print_job_new (NULL);
 	config = gnome_print_job_get_config (job);
-	dialog = gnome_print_dialog_new (job, "Sample Print Dialog", 0);
+	dialog = gnome_print_dialog_new (job, (const guchar *) "Sample Print Dialog", 0);
 
 	if (!job || !config || !dialog)
 		return TEST_RETVAL_ERROR;
@@ -440,7 +448,7 @@ test_multiple (void)
 			gtk_widget_show (dialog);
 			test_run (run_for);
 			gtk_widget_destroy (dialog);
-			dialog = gnome_print_dialog_new (job, "Sample Print Dialog", 0);
+			dialog = gnome_print_dialog_new (job, (const guchar *) "Sample Print Dialog", 0);
 		}
 		
 		for (i = 0; i < max; i++) {
@@ -451,7 +459,7 @@ test_multiple (void)
 			g_object_unref (job);
 			config = gnome_print_config_default ();
 			job = gnome_print_job_new (config);
-			dialog = gnome_print_dialog_new (job, "Sample Print Dialog", 0);
+			dialog = gnome_print_dialog_new (job, (const guchar *) "Sample Print Dialog", 0);
 		}
 	}
 	
@@ -473,25 +481,25 @@ test_paper_changes_print (void)
 	if (config == NULL)
 		return TEST_RETVAL_ERROR;
 
- 	gnome_print_config_set (config, "Printer", "GENERIC");
+ 	gnome_print_config_set (config, (const guchar *) "Printer", (const guchar *) "GENERIC");
 				
-	if (!gnome_print_config_set (config, GNOME_PRINT_KEY_PAPER_SIZE, "B3")) {
+	if (!gnome_print_config_set (config, (const guchar *) GNOME_PRINT_KEY_PAPER_SIZE, (const guchar *) "B3")) {
 		g_warning ("Could not change the Paper Size\n");
 		return TEST_RETVAL_ERROR;
 	}
-	if (!gnome_print_config_set (config, GNOME_PRINT_KEY_PAPER_ORIENTATION, "R270")) {
+	if (!gnome_print_config_set (config, (const guchar *) GNOME_PRINT_KEY_PAPER_ORIENTATION, (const guchar *) "R270")) {
 		g_warning ("Could not change the Paper Orientation\n");
 		return TEST_RETVAL_ERROR;
 	}
-	if (!gnome_print_config_set (config, GNOME_PRINT_KEY_PAGE_ORIENTATION, "R90")) {
+	if (!gnome_print_config_set (config, (const guchar *) GNOME_PRINT_KEY_PAGE_ORIENTATION, (const guchar *) "R90")) {
 		g_warning ("Could not change the Page Orientation\n");
 		return TEST_RETVAL_ERROR;
 	}
 
-	dialog = gnome_print_dialog_new (job, "Sample Print Dialog", 0);
+	dialog = gnome_print_dialog_new (job, (const guchar *) "Sample Print Dialog", 0);
 	for (i = 0; i < n; i++) {
 		gtk_widget_destroy (dialog);
-		dialog = gnome_print_dialog_new (job, "Sample Print Dialog", 0);
+		dialog = gnome_print_dialog_new (job, (const guchar *) "Sample Print Dialog", 0);
 		if (!dialog)
 			return TEST_RETVAL_ERROR;
 		gtk_widget_show (dialog);
@@ -519,7 +527,7 @@ test_simple (void)
 	job = gnome_print_job_new (config);
 	if (!job)
 		return TEST_RETVAL_ERROR;
-	dialog = gnome_print_dialog_new (NULL, "Sample Print Dialog", 0);
+	dialog = gnome_print_dialog_new (NULL, (const guchar *) "Sample Print Dialog", 0);
 	if (!dialog)
 		return TEST_RETVAL_ERROR;
 	
@@ -584,7 +592,7 @@ dialog_click_print (GtkWidget *dialog, gint msecs)
 static void
 my_draw (GnomePrintContext *gpc)
 {
-	gnome_print_beginpage (gpc, "1");
+	gnome_print_beginpage (gpc, (const guchar *) "1");
 	gnome_print_moveto (gpc, 1, 1);
 	gnome_print_lineto (gpc, 200, 200);
 	gnome_print_stroke (gpc);
@@ -619,7 +627,7 @@ gui_print (GnomePrintJob *job, gint time)
 	GtkWidget *dialog;
 	gint response;
 
-	dialog = gnome_print_dialog_new (job, "Sample Print Dialog", 0);
+	dialog = gnome_print_dialog_new (job, (const guchar *) "Sample Print Dialog", 0);
 	if (!dialog)
 		return TEST_RETVAL_ERROR;
 
@@ -659,7 +667,7 @@ test_print_ps (void)
 	if (!job || !config)
 		return TEST_RETVAL_ERROR;
 
-	gnome_print_config_set (config, "Printer", "GENERIC");
+	gnome_print_config_set (config, (const guchar *) "Printer", (const guchar *) "GENERIC");
 	retval = gui_print (job, 100);
 
 	return retval;
@@ -677,7 +685,7 @@ test_print_pdf (void)
 	if (!job || !config)
 		return TEST_RETVAL_ERROR;
 
-	gnome_print_config_set (config, "Printer", "PDF");
+	gnome_print_config_set (config, (const guchar *) "Printer", (const guchar *) "PDF");
 
 	retval = gui_print (job, 300);
 	
@@ -698,7 +706,7 @@ test_print_multiple_ps (void)
 	if (!job || !config)
 		return TEST_RETVAL_ERROR;
 	
-	gnome_print_config_set (config, "Printer", "GENERIC");
+	gnome_print_config_set (config, (const guchar *) "Printer", (const guchar *) "GENERIC");
 	
 	for (i = 0; i < max; i++) {
 		retval = gui_print (job, 100);
@@ -724,7 +732,7 @@ test_print_multiple_pdf (void)
 	if (!job || !config)
 		return TEST_RETVAL_ERROR;
 
-	gnome_print_config_set (config, "Printer", "PDF");
+	gnome_print_config_set (config, (const guchar *) "Printer", (const guchar *) "PDF");
 	
 	for (i = 0; i < max; i++) {
 		my_print (job, FALSE);		
@@ -754,12 +762,12 @@ test_print_multiple (void)
 		return TEST_RETVAL_ERROR;
 	
 	for (i = 0; i < max; i++) {
-		gnome_print_config_set (config, "Printer", "PDF");
+		gnome_print_config_set (config, (const guchar *) "Printer", (const guchar *) "PDF");
 		retval = gui_print (job, 100);
 		if (retval != TEST_RETVAL_SUCCESS)
 			return retval;
 		
-		gnome_print_config_set (config, "Printer", "GENERIC");
+		gnome_print_config_set (config, (const guchar *) "Printer", (const guchar *) "GENERIC");
 		retval = gui_print (job, 100);
 		if (retval != TEST_RETVAL_SUCCESS)
 			return retval;
@@ -772,12 +780,12 @@ test_print_multiple (void)
 	job = gnome_print_job_new (config);
 	
 	for (i = 0; i < max; i++) {
-		gnome_print_config_set (config, "Printer", "PDF");
+		gnome_print_config_set (config, (const guchar *) "Printer", (const guchar *) "PDF");
 		retval = gui_print (job, 100);
 		if (retval != TEST_RETVAL_SUCCESS)
 			return retval;
 		
-		gnome_print_config_set (config, "Printer", "GENERIC");
+		gnome_print_config_set (config, (const guchar *) "Printer", (const guchar *) "GENERIC");
 		retval = gui_print (job, 100);
 		if (retval != TEST_RETVAL_SUCCESS)
 			return retval;
@@ -917,7 +925,7 @@ main (int argc, const char * argv[])
 	parse_command_line (argc, argv, &num_test);
 
 	/* Catch sigsegv signals */
-	memset (&sig, 0, sizeof(sigaction));
+	memset (&sig, 0, sizeof (sig));
 	sig.sa_handler = handle_sigsegv;
 	sigaction (SIGSEGV, &sig, NULL);
 
@@ -940,14 +948,23 @@ main (int argc, const char * argv[])
 		gchar *s;
 		job = gnome_print_job_new (NULL);
 		config = gnome_print_job_get_config (job);
-		if (FALSE) {
-			dialog = gnome_print_dialog_new (job, "Test", 0);
+		if (TRUE) {
+			GnomePrintContext *pc = NULL;
+
+			g_object_get (G_OBJECT (job), "context", &pc, NULL);
+			my_draw (pc);
+			my_draw (pc);
+			dialog = gnome_print_dialog_new (job, (const guchar *) "Test",
+					GNOME_PRINT_DIALOG_RANGE | GNOME_PRINT_DIALOG_COPIES);
+			gnome_print_dialog_construct_range_any (GNOME_PRINT_DIALOG (dialog),
+					GNOME_PRINT_RANGE_ALL |
+					GNOME_PRINT_RANGE_SELECTION, NULL, NULL, NULL);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
 		} else {
-			dialog = gnome_print_dialog_new (job, "Test dialog 1", 0);
+			dialog = gnome_print_dialog_new (job, (const guchar *) "Test dialog 1", 0);
 			gtk_widget_show (dialog);
-			dialog = gnome_print_dialog_new (job, "Test dialog 2", 0);
+			dialog = gnome_print_dialog_new (job, (const guchar *) "Test dialog 2", 0);
 			gtk_widget_show (dialog);
 			gtk_main ();
 		}
